@@ -1,4 +1,4 @@
-#$Header: /home/cvs/date-iso/lib/Date/ISO.pm,v 1.24 2001/11/27 02:15:15 rbowen Exp $
+#$Header: /home/cvs/date-iso/lib/Date/ISO.pm,v 1.25 2001/11/27 02:44:43 rbowen Exp $
 package Date::ISO;
 
 use strict;
@@ -8,7 +8,7 @@ use Date::ICal;
 use vars qw( $VERSION @ISA @EXPORT );
 
 @ISA = qw( Exporter Date::ICal );
-$VERSION = (qw'$Revision: 1.24 $')[1];
+$VERSION = (qw'$Revision: 1.25 $')[1];
 
 @EXPORT = qw(iso inverseiso localiso);
 
@@ -84,6 +84,7 @@ Time values are not supported at this time.
 sub new {    #{{{
     my $class = shift;
     my %args  = @_;
+    my $offset = $args{offset} || 0;
     my $self;
 
 # Deprecated argument form {{{
@@ -104,14 +105,15 @@ sub new {    #{{{
 
             $self = $class->SUPER::new( year => $1, 
                     month => $2, day => $3, hour => 0,
-                    min => 0, sec => 0, offset => 0 );
+                    min => 0, sec => 0, offset => $args{offset} );
         }
 
         # 199702 format
         elsif ( $args{iso} =~ m/^(\d\d\d\d)(\d\d)$/ ) {
             
             $self = $class->SUPER::new( year => $1, month => $2,
-                day => 1, hour => 0, min => 0, sec => 0, offset => 0 );
+                day => 1, hour => 0, min => 0, sec => 0,
+                offset => $args{offset} );
         }
 
         # 1997-W06-2, 1997W062,, 1997-06-2, 1997062, 1996-06, 1997W06  formats
@@ -124,7 +126,7 @@ sub new {    #{{{
 
             $self = $class->SUPER::new( year => $year, month => $month,
                 day => $day, hour => 0, min => 0, sec => 0,
-                offset => 0 );
+                offset => $args{offset} );
 
         # Don't know what the format was
         }
@@ -378,7 +380,7 @@ Rich Bowen (rbowen@rcbowen.com)
 
 =head1 DATE
 
-$Date: 2001/11/27 02:15:15 $
+$Date: 2001/11/27 02:44:43 $
 
 =head1 Additional comments
 
@@ -421,6 +423,10 @@ back what we started with. I'm not at all sure what is going on.
 =head1 Version History
 
     $Log: ISO.pm,v $
+    Revision 1.25  2001/11/27 02:44:43  rbowen
+    If an offset is not provided, explicitly set to 0. We are dealing with
+    dates, not times.
+
     Revision 1.24  2001/11/27 02:15:15  rbowen
     Explicitly set offset to 0 always.
 
